@@ -2,6 +2,6 @@
 
 #define HAVE_GETGROUPLIST 1
 
-#define KDE4_DEFAULT_HOME ".kde4"
-
 #define HAVE_DLADDR 1
+
+#define HAVE_QTDBUS 1
