@@ -1,5 +1,5 @@
-#define HAVE_FAM 0
-
 #define HAVE_SYS_INOTIFY_H 1
 
+#define HAVE_INOTIFY_DIRECT_READV 0
+
 #define HAVE_QTDBUS 1
